@@ -1480,7 +1480,9 @@ class Destination(TreeObject):
         self[NameObject("/Type")] = typ
 
         # from table 8.2 of the PDF 1.7 reference.
-        if typ == "/XYZ":
+        if len(args) == 0:
+            pass
+        elif typ == "/XYZ":
             if len(args) < 3:  # zoom is missing
                 args.append(NumberObject(0.0))
             (
